
#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""


from smartlingApiSdk.ApiV2 import ApiV2

class StringsApi(ApiV2):

    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None, permanentHeaders={}, env='prod'):
        ApiV2.__init__(self, userIdentifier, userSecret, projectId, proxySettings, permanentHeaders=permanentHeaders, env=env)

    def addStringsToProject(self, strings, placeholderFormat, placeholderFormatCustom, namespace, **kwargs):
        """
            method  :  POST
            api url :  /strings-api/v2/projects/{projectId}
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingStringJSON" https://api.smartling.com/strings-api/v2/projects/$smartlingProjectId
            Responses:
                200 : OK
                202 : ACCEPTED
            details :  https://api-reference.smartling.com/#operation/addStringsToProject
        """
        kw = {
            'strings':strings,
            'placeholderFormat':placeholderFormat,
            'placeholderFormatCustom':placeholderFormatCustom,
            'namespace':namespace,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/strings-api/v2/projects/{projectId}', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getAddStringsToProjectRequestStatus(self, processUid, **kwargs):
        """
            method  :  GET
            api url :  /strings-api/v2/projects/{projectId}/processes/{processUid}
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -G https://api.smartling.com/strings-api/v2/projects/$smartlingProjectId/processes/$processUid
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getAddStringsToProjectRequestStatus
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/strings-api/v2/projects/{projectId}/processes/{processUid}', processUid=processUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getAllSourceStringsByProject(self, hashcodes=[], fileUri='', limit='', offset='', **kwargs):
        """
            method  :  POST
            api url :  /strings-api/v2/projects/{projectId}/source-strings
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -G -d "fileUri=$smartlingFileUri" https://api.smartling.com/strings-api/v2/projects/$smartlingProjectId/source-strings
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getAllSourceStringsByProject
        """
        kw = {
            'hashcodes':hashcodes,
            'fileUri':fileUri,
            'limit':limit,
            'offset':offset,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/strings-api/v2/projects/{projectId}/source-strings', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getAllTranslationsByProject(self, targetLocaleId, hashcodes=[], retrievalType='', fileUri='', limit='', offset='', **kwargs):
        """
            method  :  POST
            api url :  /strings-api/v2/projects/{projectId}/translations
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -G https://api.smartling.com/strings-api/v2/projects/$smartlingProjectId/translations
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getAllTranslationsByProject
        """
        kw = {
            'targetLocaleId':targetLocaleId,
            'hashcodes':hashcodes,
            'retrievalType':retrievalType,
            'fileUri':fileUri,
            'limit':limit,
            'offset':offset,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/strings-api/v2/projects/{projectId}/translations', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limit
"""

from builder.Parameters import Code
from builder.ExampleData import TestData

testsOrder = [
   'addJob',
   'addLocaleToJob',
   'addStringsToJob',
   'addFileToJob',
   'getJobFilesList',
   'getJobFileProgress',
   'authorizeJob',
   'modifyScheduleItemsForTranslationJob',
   'createCustomField',
   'assignCustomFieldsToProject',
   'updateCustomField',
   'removeFileFromJob',
   'removeStringsFromJob',
   'getJobLastCompletionDatesPerLocale',
   'findScheduleForTranslationJob',
   'removeLocaleFromJob',
   'getJobsByProject',
   'updateJob',
   'getJobProgress',
   'getJobDetails',
   'getStringsForTranslationJob',
   'findJobsByStrings',
   'searchForJob',
   'cancelJob',
   'deleteJob',
   'getProjectCustomFields',
   'getAccountCustomFields',
   'getJobsByAccount',
]

extraInitializations = '''
        # setUp code add-on #
        self.jobname = 'test_job_'+str(int(time.time()))
        self.deleteTestJobs()

    def deleteTestJobs(self):
        response,code = self.jobs_api.getJobsByProject()
        c = 0
        sz = len(response.data.items)
        for job in response.data.items:
            c += 1
            if job['jobName'].startswith('test_job_'):
                uid = job['translationJobUid']
                cres, cstatus = self.jobs_api.cancelJob(uid, 'test reason')
                res, status = self.jobs_api.deleteJob(uid)
                print (c, 'of', sz, uid, cstatus, status)

    def dateTimeStr(self, offset):
        return datetime.datetime.fromtimestamp(time.time()+offset).strftime("%Y-%m-%dT%H:%M:%SZ")
'''

jobUidCode = Code('self.test_job_uid')

testDecorators = {
'addJob':TestData(
    {
        'jobName' : Code('self.jobname'),
        'targetLocaleIds' : Code('[self.MY_LOCALE,]'),
        'description' : 'testDescription',
        'dueDate' : Code('self.dateTimeStr(3600*24*30)'),
        'referenceNumber' : 'testReferenceNumber',
        'callbackUrl' : 'https://www.callback.com/smartling/job',
        'callbackMethod': 'GET',
        'customFields' : [],
    },
    [],
    ["self.test_job_uid = res.data.translationJobUid",]
),

'updateJob':  TestData(
    {
        'translationJobUid':Code('self.test_job_uid'),
        'jobName' : Code('"new name" + self.jobname'),
        'description' : 'new Description',
        'dueDate' : Code('self.dateTimeStr(3600*24*120)'),
        'referenceNumber' : 'new ReferenceNumber',
        'callbackUrl' : 'https://www.callback.com/smartling/new_job',
        'callbackMethod': 'POST',
        'customFields' : [],
    }
),

'findJobsByStrings' : TestData(
    {'hashcodes':Code('[]'), 'localeIds' : Code('[self.MY_LOCALE,]'),}
),

'getAccountCustomFields' : TestData(
    {'accountUid':Code('self.MY_ACCOUNT_UID')}
),

'assignCustomFieldsToProject' : TestData(
    {'accountUid':Code('self.MY_ACCOUNT_UID'),
     'CustomFieldAssignmentList': Code('[{"fieldUid":self.fieldUid},]')
    },
'''
resp, code = self.jobs_api.getAccountCustomFields(self.MY_ACCOUNT_UID)
self.fieldUid=None
for fld in resp.data.items:
    if 'python-sdk-test' == fld['fieldName']:
        self.fieldUid = fld['fieldUid']

'''.split('\n')
),

'updateCustomField' : TestData(
    {'accountUid':Code('self.MY_ACCOUNT_UID'),
     "fieldUid": Code("self.fieldUid"),
     "fieldName": "python-sdk-test",
     "enabled": True,
     "required": False,
     "searchable": True,
     "displayToTranslators": True,
     "options": [],
     "defaultValue": "New default field value",
     "description": "New custom field example"
     },
),


'createCustomField' : TestData(
    {'accountUid':Code('self.MY_ACCOUNT_UID'),
      "type": "SHORT_TEXT",
      "fieldName": "python-sdk-test",
      "enabled": True,
      "required": False,
      "searchable": True,
      "displayToTranslators": True,
      "options": [],
      "defaultValue": "default field value",
      "description": "Custom field example"

    },
    ['self.jobs_api.httpClient.ignore_errors=True'],
    ['self.jobs_api.httpClient.ignore_errors=False'],
    customTestCheck='''
if 400 == status:
    assert_equal(True, 'Field name must be unique within account' in str(res))
else:
    assert_equal(True, status in [200,202])
    assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKED])
''',
    isApiV2Response= False,
),

'getJobProgress' :                     TestData({'translationJobUid':jobUidCode}),
'getJobDetails' :                      TestData({'translationJobUid':jobUidCode}),
'deleteJob' :                          TestData({'translationJobUid':jobUidCode}),
'getStringsForTranslationJob' :        TestData({'translationJobUid':jobUidCode}),
'getJobLastCompletionDatesPerLocale' : TestData({'translationJobUid':jobUidCode}),
'findScheduleForTranslationJob' :      TestData({'translationJobUid':jobUidCode}),
'getJobFilesList' :                    TestData({'translationJobUid':jobUidCode}),

'authorizeJob' : TestData({
    'localeWorkflows': Code(' [ { "targetLocaleId": "zh-TW", "workflowUid": "748398939979" } ]'),
    'translationJobUid': jobUidCode,
}
),

'modifyScheduleItemsForTranslationJob' : TestData({
    'schedules': Code(' [ { "targetLocaleId": "zh-TW", "workflowStepUid": "7f6126eff318", "dueDate": self.dateTimeStr(3600*24*30)} ]'),
    'translationJobUid': jobUidCode,
}
),

'addStringsToJob' : TestData({
    'hashcodes' : Code('["e1159037badca0a2a618f62c50eff1bb", ] # use your string hashcodes list here'),
    'moveEnabled': Code('False'),
    'targetLocaleIds' : Code('[self.MY_LOCALE,]'),
    'translationJobUid': jobUidCode,
}, [], [
    'assert_equal(1, res.data.successCount, "addStringsToJob will fail if string was already in other job")',
]
),

'removeStringsFromJob' : TestData({
    'hashcodes' : Code('["e1159037badca0a2a618f62c50eff1bb", ] # use your string hashcodes list here'),
    'localeIds' : Code('[self.MY_LOCALE,]'),
    'translationJobUid': jobUidCode,
}
),

'searchForJob' : TestData({
    'fileUris':Code('[]'),
    'hashcodes':Code('[]'),
    'translationJobUids':Code('[self.test_job_uid]'),
}),


'cancelJob' : TestData(
    {'translationJobUid':jobUidCode, 'reason':'test reason'}
),

'getJobsByProject' : TestData({'jobName':Code('self.jobname')}),

'addLocaleToJob' : TestData({'translationJobUid':jobUidCode,
                                        'targetLocaleId' : Code('"zh-TW" #use your other locale here'),
                                        'syncContent' : Code('True')
                                        }),

'removeLocaleFromJob' : TestData({'translationJobUid':jobUidCode,
                                        'targetLocaleId' : Code('"zh-TW" #use already added locale here'),
                                        }),

'addFileToJob' : TestData({'translationJobUid':jobUidCode,
                                      'targetLocaleIds' : Code('[self.MY_LOCALE,]'),
                                      'fileUri' : Code('"test_import.xml_2.2.4_1629202583.584802" #use your actual file uri uploaded earielr to Smartling')
                                      }),

'getJobFileProgress' : TestData({'translationJobUid':jobUidCode,
                                      'fileUri' : Code('"test_import.xml_2.2.4_1629202583.584802" #use your actual file uri uploaded earielr to Smartling')
                                      }),
'removeFileFromJob' : TestData({'translationJobUid':jobUidCode,
                                      'fileUri' : Code('"test_import.xml_2.2.4_1629202583.584802" #use your actual file uri uploaded earielr to Smartling')
                                      }),
}


#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import os


class CredentialsNotSet(Exception):
    noKeyMessage = """ 
     don't forget to set real MY_PROJECT_ID, MY_USER_IDENTIFIER, MY_USER_SECRET, MY_LOCALE
     in Credentials class
     or use environment variables:
     export SL_LOCALE=**-**
     export SL_USER_IDENTIFIER=******************************
     export SL_USER_SECRET=*******************************************************
     
     #optional
     export SL_ACCOUNT_UID=******* #required only to list projects api call
     export SL_PROJECT_ID=******* #required for api calls `projects` and `project_details`
    """

    def __init__(self, id, env):
        self.id = id
        self.env = env

    def getMessage(self):
        res = self.noKeyMessage
        if 'stg' == self.env:
            res = res.replace('SL_USER_IDENTIFIER=', 'SL_USER_IDENTIFIER_STG=')
            res = res.replace('SL_USER_SECRET=', 'SL_USER_SECRET_STG=')
        return res

    def __str__(self):
        return "Missing:" + self.id + self.getMessage()


class Credentials():

    MY_PROJECT_ID = "CHANGE_ME"
    MY_ACCOUNT_UID = "CHANGE_ME"
    MY_USER_IDENTIFIER = "CHANGE_ME"
    MY_USER_SECRET = "CHANGE_ME"
    MY_LOCALE ="CHANGE_ME"

    CREDS = ("PROJECT_ID", "ACCOUNT_UID", "USER_IDENTIFIER", "USER_SECRET", "LOCALE")
    OPTIONAL_CREDS = ("ACCOUNT_UID")
   
    def __init__(self, env='prod'):
        for id in self.CREDS:
            cred = "MY_"+id
            suffix = ''
            if env == 'stg' and id.startswith("USER_"):
                suffix = '_STG'
            value = getattr(self, cred + suffix, "CHANGE_ME")
            if "CHANGE_ME" == value:
                value = os.environ.get('SL_' + id + suffix, getattr(self, cred))
            if "CHANGE_ME" == value and id not in self.OPTIONAL_CREDS:
                raise CredentialsNotSet('SL_' + id + suffix, env)
            setattr(self, cred, value)



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import os
import sys
import threading

lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from smartlingApi.FilesApi import FilesApi
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.Credentials import Credentials

#File attributes to upload to Smartling server
FILE_TYPE = "javaProperties"
FILE_NAME = "java.properties"
FILE_PATH = "../resources/"

#set Smartling creadentials via helper Credentials class
credentials = Credentials() #Gets your Smartling credetnials from environment variables
MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
MY_USER_SECRET = credentials.MY_USER_SECRET
MY_PROJECT_ID = credentials.MY_PROJECT_ID
MY_LOCALE = credentials.MY_LOCALE

#set proxy settigns if necessary
useProxy = False
if useProxy :
    proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port")
else:
    proxySettings = None
def single_thread():
    #initializa api object
    fapi = FilesApi( MY_USER_IDENTIFIER, MY_USER_SECRET, MY_PROJECT_ID, proxySettings)

    #Upload file to Smartling

    print("\nUploading ...")
    path = FILE_PATH + FILE_NAME

    customFileUri = "/simple/test"
    #parameter `fileUri` is optional, if not set - value of `path` is be used as fiel uri here and
    #should be used in all requests that need file uri
    #like fapi.status, fapi.get, fapi.delete
    resp, code = fapi.uploadSourceFile(file=path, fileType=FILE_TYPE, fileUri = customFileUri, authorize=True)
    print(resp, code)
    if 200!=code:
        raise Exception("failed")

    #List uploaded files
    print("\nList ...")
    resp, code = fapi.getFileTypesList()
    print("items size= ", len(resp.data.items))
    #print(code, resp)

    #check file status
    print("\nFile status ...")
    resp, code = fapi.getFileTranslationStatusAllLocales(customFileUri)
    #print(code, resp)
    print(resp.data.fileUri)
    print("items size=", len(resp.data.items))

    #read uplaoded file
    print("\nRead file from server ...")
    #resp, code = fapi.get(customFileUri, MY_LOCALE)
    print(resp, code)

    #delete file
    print("\nDelete file ...")
    resp, code = fapi.deleteUploadedSourceFile(customFileUri)
    print(resp, code)

def start_thread():
    thr = threading.Thread( None, single_thread, None, () )
    thr.start()

single_threaded = True
if single_threaded:
    single_thread()
else:
    start_thread()
    start_thread()




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limit
"""


class TestData:
    def __init__(self, fields, pre = [], post = [], customTestCheck ='', isApiV2Response = True):
        self.fields = fields
        self.preCalls = pre
        self.postCalls = post
        self.customTestCheck = customTestCheck
        self.is_apiv2_response = isApiV2Response

COPYRIGHT_HEADER = '''
#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""
'''

EXAMPLE_HEADER= COPYRIGHT_HEADER + """
import os
import sys
import time, datetime

lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from smartlingApi.{API_NAME} import {API_NAME}
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.Credentials import Credentials

isPython3 =  sys.version_info[:2] >= (3,0)
{EXTRA_IMPORTS}

def assert_equal(a,b, comment=''):
    if a != b :
        err = "Assertion Failed: '%s' != '%s' %s" % (a,b, comment)
        if not isPython3 and type(err) == str:
            err = err.decode('utf-8', 'ignore')
        raise Exception(repr(err))

class test{API_NAME}(object):

    CODE_SUCCESS_TOKEN = 'SUCCESS'
    ACCEPTED_TOKEN = 'ACCEPTED'

    def tearDown(self):
        print("tearDown", "OK")

    def setUp(self):
        credentials = Credentials() #Gets your Smartling credetnials from environment variables
        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID

        #needed for testProjects
        self.MY_ACCOUNT_UID = credentials.MY_ACCOUNT_UID
        self.MY_LOCALE = credentials.MY_LOCALE

        if self.MY_ACCOUNT_UID == "CHANGE_ME":
            print("can't test projects api call, set self.MY_ACCOUNT_UID or export SL_ACCOUNT_UID=*********")
            return

        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None

        self.{api_name}_api = {API_NAME}(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings)

        print("setUp", "OK", "\\n")
"""

EXAMPLE_FOOTER = """
def example():
    t = test{API_NAME}()
    t.setUp()
    %s
    t.tearDown()

example()
"""

TESTS_FOOTER = """
    def test_all(self):
        t = self
        %s
"""




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""


from smartlingApiSdk.ApiV2 import ApiV2

class JobsApi(ApiV2):

    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None, permanentHeaders={}, env='prod'):
        ApiV2.__init__(self, userIdentifier, userSecret, projectId, proxySettings, permanentHeaders=permanentHeaders, env=env)

    def getJobsByAccount(self, accountUid, jobName='', projectIds=[], translationJobStatus=[], withPriority='', limit=0, offset=0, sortBy='', sortDirection='', **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/accounts/{accountUid}/jobs
            as curl :  curl -H "Authorization: Bearer $smartlingToken" https://api.smartling.com/jobs-api/v3/accounts/$smartlingAccountId/jobs
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getJobsByAccount
        """
        kw = {
            'jobName':jobName,
            'projectIds':projectIds,
            'translationJobStatus':translationJobStatus,
            'withPriority':withPriority,
            'limit':limit,
            'offset':offset,
            'sortBy':sortBy,
            'sortDirection':sortDirection,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/accounts/{accountUid}/jobs', accountUid=accountUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getJobsByProject(self, jobName='', jobNumber='', translationJobUids=[], translationJobStatus=[], limit=0, offset=0, sortBy='', sortDirection='', **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/projects/{projectId}/jobs
            as curl :  curl -H "Authorization: Bearer $smartlingToken" https://api.smartling.com/jobs-api/v3/projects/$smartlingProjectId/jobs
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getJobsByProject
        """
        kw = {
            'jobName':jobName,
            'jobNumber':jobNumber,
            'translationJobUids':translationJobUids,
            'translationJobStatus':translationJobStatus,
            'limit':limit,
            'offset':offset,
            'sortBy':sortBy,
            'sortDirection':sortDirection,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def addJob(self, jobName, targetLocaleIds, description, dueDate, referenceNumber, callbackUrl, callbackMethod, customFields, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingJobJSON" https://api.smartling.com/jobs-api/v3/projects/$smartlingProjectId/jobs
            Responses:
                200 : OK
                400 : Validation error during job creation.
            details :  https://api-reference.smartling.com/#operation/addJob
        """
        kw = {
            'jobName':jobName,
            'targetLocaleIds':targetLocaleIds,
            'description':description,
            'dueDate':dueDate,
            'referenceNumber':referenceNumber,
            'callbackUrl':callbackUrl,
            'callbackMethod':callbackMethod,
            'customFields':customFields,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def findJobsByStrings(self, hashcodes, localeIds, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs/find-jobs-by-strings
            Responses:
                200 : OK
                400 : Validation error response
            details :  https://api-reference.smartling.com/#operation/findJobsByStrings
        """
        kw = {
            'hashcodes':hashcodes,
            'localeIds':localeIds,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/find-jobs-by-strings', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getStringsForTranslationJob(self, translationJobUid, targetLocaleId='', limit=0, offset=0, **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/strings
            Responses:
                200 : OK
                404 : Job not found error
            details :  https://api-reference.smartling.com/#operation/getStringsForTranslationJob
        """
        kw = {
            'targetLocaleId':targetLocaleId,
            'limit':limit,
            'offset':offset,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/strings', translationJobUid=translationJobUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def addStringsToJob(self, translationJobUid, hashcodes, moveEnabled, targetLocaleIds, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/strings/add
            Responses:
                200 : OK
                202 : ACCEPTED
                400 : Validation error response
            details :  https://api-reference.smartling.com/#operation/addStringsToJob
        """
        kw = {
            'hashcodes':hashcodes,
            'moveEnabled':moveEnabled,
            'targetLocaleIds':targetLocaleIds,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/strings/add', translationJobUid=translationJobUid, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def removeStringsFromJob(self, translationJobUid, hashcodes, localeIds, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/strings/remove
            Responses:
                200 : OK
                202 : ACCEPTED
            details :  https://api-reference.smartling.com/#operation/removeStringsFromJob
        """
        kw = {
            'hashcodes':hashcodes,
            'localeIds':localeIds,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/strings/remove', translationJobUid=translationJobUid, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def closeJob(self, translationJobUid, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/close
            Responses:
                200 : OK
                400 : Validation error when closing a job
            details :  https://api-reference.smartling.com/#operation/closeJob
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/close', translationJobUid=translationJobUid, **kwargs)
        response, status = self.command('POST', url, kw)
        return response, status


    def cancelJob(self, translationJobUid, reason, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/cancel
            Responses:
                200 : OK
                202 : ACCEPTED
                400 : Validation error when cancelling a job
                401 : Authentication error
            details :  https://api-reference.smartling.com/#operation/cancelJob
        """
        kw = {
            'reason':reason,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/cancel', translationJobUid=translationJobUid, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def authorizeJob(self, translationJobUid, localeWorkflows, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/authorize
            Responses:
                200 : OK
                400 : Validation error when authorizing a job
            details :  https://api-reference.smartling.com/#operation/authorizeJob
        """
        kw = {
            'localeWorkflows':localeWorkflows,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/authorize', translationJobUid=translationJobUid, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getJobDetails(self, translationJobUid, **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}
            Responses:
                200 : OK
                404 : Job not found error
            details :  https://api-reference.smartling.com/#operation/getJobDetails
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}', translationJobUid=translationJobUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def updateJob(self, translationJobUid, jobName, description, dueDate, referenceNumber, callbackUrl, callbackMethod, customFields, **kwargs):
        """
            method  :  PUT
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}
            Responses:
                200 : OK
                400 : Validation error on updating a job
                404 : Job not found error
            details :  https://api-reference.smartling.com/#operation/updateJob
        """
        kw = {
            'jobName':jobName,
            'description':description,
            'dueDate':dueDate,
            'referenceNumber':referenceNumber,
            'callbackUrl':callbackUrl,
            'callbackMethod':callbackMethod,
            'customFields':customFields,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}', translationJobUid=translationJobUid, **kwargs)
        response, status = self.commandJson('PUT', url, kw)
        return response, status


    def deleteJob(self, translationJobUid, **kwargs):
        """
            method  :  DELETE
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}
            Responses:
                200 : OK
                400 : Validation error when deleting a job
                401 : Authentication error
            details :  https://api-reference.smartling.com/#operation/deleteJob
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}', translationJobUid=translationJobUid, **kwargs)
        response, status = self.command('DELETE', url, kw)
        return response, status


    def searchForJob(self, fileUris, hashcodes, translationJobUids, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs/search
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/searchForJob
        """
        kw = {
            'fileUris':fileUris,
            'hashcodes':hashcodes,
            'translationJobUids':translationJobUids,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/search', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getJobAsyncProcessStatus(self, translationJobUid, processUid, **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/processes/{processUid}
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getJobAsyncProcessStatus
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/processes/{processUid}', translationJobUid=translationJobUid, processUid=processUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def addFileToJob(self, translationJobUid, fileUri, targetLocaleIds, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/file/add
            Responses:
                200 : OK
                202 : ACCEPTED
                400 : Validation error adding file to a job
                423 : The requested file is currently being processed by another operation. The file will be unlocked after the operation completes.
            details :  https://api-reference.smartling.com/#operation/addFileToJob
        """
        kw = {
            'fileUri':fileUri,
            'targetLocaleIds':targetLocaleIds,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/file/add', translationJobUid=translationJobUid, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def removeFileFromJob(self, translationJobUid, fileUri, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/file/remove
            Responses:
                200 : OK
                202 : ACCEPTED
                404 : Not found validation error
            details :  https://api-reference.smartling.com/#operation/removeFileFromJob
        """
        kw = {
            'fileUri':fileUri,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/file/remove', translationJobUid=translationJobUid, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getJobFilesList(self, translationJobUid, limit=0, offset=0, **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/files
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getJobFilesList
        """
        kw = {
            'limit':limit,
            'offset':offset,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/files', translationJobUid=translationJobUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def addLocaleToJob(self, translationJobUid, targetLocaleId, syncContent, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/locales/{targetLocaleId}
            Responses:
                200 : OK
                202 : ACCEPTED
            details :  https://api-reference.smartling.com/#operation/addLocaleToJob
        """
        kw = {
            'syncContent':syncContent,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/locales/{targetLocaleId}', translationJobUid=translationJobUid, targetLocaleId=targetLocaleId, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def removeLocaleFromJob(self, translationJobUid, targetLocaleId, **kwargs):
        """
            method  :  DELETE
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/locales/{targetLocaleId}
            Responses:
                200 : OK
                202 : ACCEPTED
            details :  https://api-reference.smartling.com/#operation/removeLocaleFromJob
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/locales/{targetLocaleId}', translationJobUid=translationJobUid, targetLocaleId=targetLocaleId, **kwargs)
        response, status = self.command('DELETE', url, kw)
        return response, status


    def getJobFileProgress(self, translationJobUid, fileUri, **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/file/progress
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getJobFileProgress
        """
        kw = {
            'fileUri':fileUri,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/file/progress', translationJobUid=translationJobUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getJobProgress(self, translationJobUid, targetLocaleId='', **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/progress
            Responses:
                200 : OK
                404 : Not found error
            details :  https://api-reference.smartling.com/#operation/getJobProgress
        """
        kw = {
            'targetLocaleId':targetLocaleId,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/progress', translationJobUid=translationJobUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getJobLastCompletionDatesPerLocale(self, translationJobUid, **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/locales-completion-dates
            Responses:
                200 : OK
                404 : Not found error
            details :  https://api-reference.smartling.com/#operation/getJobLastCompletionDatesPerLocale
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/locales-completion-dates', translationJobUid=translationJobUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def findScheduleForTranslationJob(self, translationJobUid, **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/schedule
            Responses:
                200 : OK
                404 : Not found error
            details :  https://api-reference.smartling.com/#operation/findScheduleForTranslationJob
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/schedule', translationJobUid=translationJobUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def modifyScheduleItemsForTranslationJob(self, translationJobUid, schedules, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/schedule
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/modifyScheduleItemsForTranslationJob
        """
        kw = {
            'schedules':schedules,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/jobs/{translationJobUid}/schedule', translationJobUid=translationJobUid, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getProjectCustomFields(self, **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/projects/{projectId}/custom-fields
            Responses:
                200 : OK
                404 : Not found error
            details :  https://api-reference.smartling.com/#operation/getProjectCustomFields
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/custom-fields', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def assignCustomFieldsToProject(self, CustomFieldAssignmentList, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/projects/{projectId}/custom-fields
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/assignCustomFieldsToProject
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/projects/{projectId}/custom-fields', **kwargs)
        response, status = self.commandJson('POST', url, CustomFieldAssignmentList)
        return response, status


    def getAccountCustomFields(self, accountUid, searchableOnly='', enabledOnly='', **kwargs):
        """
            method  :  GET
            api url :  /jobs-api/v3/accounts/{accountUid}/custom-fields
            Responses:
                200 : OK
                404 : Not found error
            details :  https://api-reference.smartling.com/#operation/getAccountCustomFields
        """
        kw = {
            'searchableOnly':searchableOnly,
            'enabledOnly':enabledOnly,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/accounts/{accountUid}/custom-fields', accountUid=accountUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def createCustomField(self, accountUid, type, fieldName, enabled, required, searchable, displayToTranslators, options, defaultValue, description, **kwargs):
        """
            method  :  POST
            api url :  /jobs-api/v3/accounts/{accountUid}/custom-fields
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/createCustomField
        """
        kw = {
            'type':type,
            'fieldName':fieldName,
            'enabled':enabled,
            'required':required,
            'searchable':searchable,
            'displayToTranslators':displayToTranslators,
            'options':options,
            'defaultValue':defaultValue,
            'description':description,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/accounts/{accountUid}/custom-fields', accountUid=accountUid, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def updateCustomField(self, accountUid, fieldUid, fieldName, enabled, required, searchable, displayToTranslators, options, defaultValue, description, **kwargs):
        """
            method  :  PUT
            api url :  /jobs-api/v3/accounts/{accountUid}/custom-fields/{fieldUid}
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/updateCustomField
        """
        kw = {
            'fieldName':fieldName,
            'enabled':enabled,
            'required':required,
            'searchable':searchable,
            'displayToTranslators':displayToTranslators,
            'options':options,
            'defaultValue':defaultValue,
            'description':description,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/jobs-api/v3/accounts/{accountUid}/custom-fields/{fieldUid}', accountUid=accountUid, fieldUid=fieldUid, **kwargs)
        response, status = self.commandJson('PUT', url, kw)
        return response, status




    
#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import os
import sys
import time, datetime

lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from smartlingApi.StringsApi import StringsApi
from smartlingApi.FilesApi   import FilesApi
from smartlingApi.AccountProjectsApi   import AccountProjectsApi
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.Credentials import Credentials

isPython3 =  sys.version_info[:2] >= (3,0)

def assert_equal(a,b, comment=''):
    if a != b :
        err = "Assertion Failed: '%s' != '%s' %s" % (a,b, comment)
        if not isPython3 and type(err) == str:
            err = err.decode('utf-8', 'ignore')
        raise Exception(repr(err))

class MultipeProjectsExample(object):

    def __init__(self):
        credentials = Credentials('stg') #Gets your Smartling credetnials from environment variables
        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID

        #needed for testProjects
        self.MY_ACCOUNT_UID = credentials.MY_ACCOUNT_UID
        self.MY_LOCALE = credentials.MY_LOCALE

        if self.MY_ACCOUNT_UID == "CHANGE_ME":
            print("can't test projects api call, set self.MY_ACCOUNT_UID or export SL_ACCOUNT_UID=*********")
            return

        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None

        self.strings_api = StringsApi(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings, env='stg')
        self.files_api = FilesApi(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings, env='stg')
        self.projects_api = AccountProjectsApi(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings, env='stg')

    def filterResponseListValue(self, res, key):
        return [x[key] for x in res.data.items]

    def getAllSourceStringsByProject(self, projectId, fileUri):
        '''
            example of usage custom projectId - add it as named parameter to any api call
        '''
        res, status = self.strings_api.getAllSourceStringsByProject(fileUri = fileUri, projectId=projectId)
        return self.filterResponseListValue(res, 'parsedStringText')


    def getAllFilesByProject(self, projectId):
        '''
            anoher example of usage custom projectId - add it as named parameter to any api call
        '''
        res, code = self.files_api.getRecentlyUploadedSourceFilesList(projectId=projectId)
        return self.filterResponseListValue(res, 'fileUri')

    def getAccountProjects(self):
        res, code  = self.projects_api.getProjectsByAccount(self.MY_ACCOUNT_UID, limit=10)
        return self.filterResponseListValue(res, 'projectId')

def exampleMultipeProjects():
    '''
        note - to access multiple projects one should have access to all projects
        here 10 projects within same account are used to get urls and strings per url
    '''
    mpe = MultipeProjectsExample()
    project_uids = mpe.getAccountProjects()
    popularity = {}
    for uid in project_uids[:]:
        files = mpe.getAllFilesByProject(uid)
        print("processing %s : %d files" % (uid, len(files)))
        for file_uri in files:
            strings =  mpe.getAllSourceStringsByProject(uid, file_uri)
            for str in strings:
                projects = popularity.get(str,{})
                projects[uid] = 1
                popularity[str] = projects

    items = list(popularity.items())
    items.sort(key=lambda x:len(x[1]) )
    items.reverse()
    print ("."*120)
    print ("top 5 popular strings:")
    print ("."*120)
    for str, uids in items[:5]:
        print("%s : %d projects : %s" % (str, len(uids), list(uids.keys())))
        print ("."*120)

exampleMultipeProjects()


#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limit
"""

from builder.Parameters import Code
from builder.ExampleData import TestData

testsOrder = [
    "generateJobFuzzyEstimateReports",
    "getJobFuzzyEstimateReports",
    "generateJobCostEstimateReports",
    "getJobCostEstimateReports",
    "getJobEstimateReportStatus",
    "getJobEstimateReport",
    "modifyJobEstimateReportTags",
    "exportJobEstimationReport",
    "deleteJobEstimateReport",
]

tearDown = '''
        self.jobs_api.cancelJob(self.test_job_uid, 'test reason')
        self.jobs_api.deleteJob(translationJobUid=self.test_job_uid)
'''

imports = "from smartlingApi.JobsApi import JobsApi"

extraInitializations = '''
        self.addTestJob(proxySettings)
        self.addStringsToJob()

    def dateTimeStr(self, offset):
        return datetime.datetime.fromtimestamp(time.time()+offset).strftime("%Y-%m-%dT%H:%M:%SZ")
         
    def addTestJob(self, proxySettings):
        self.jobs_api = JobsApi(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings, env='prod')
        self.jobname = 'test_job_'+str(int(time.time()))
        jobName=self.jobname
        targetLocaleIds=["zh-TW",]
        description='testDescription'
        dueDate=self.dateTimeStr(3600*24*30)
        referenceNumber='testReferenceNumber'
        callbackUrl='https://www.callback.com/smartling/job'
        callbackMethod='GET'
        customFields=[]
        res, status = self.jobs_api.addJob(jobName=jobName, targetLocaleIds=targetLocaleIds, description=description, dueDate=dueDate, referenceNumber=referenceNumber, callbackUrl=callbackUrl, callbackMethod=callbackMethod, customFields=customFields)
        self.test_job_uid = res.data.translationJobUid

    def addStringsToJob(self):
        translationJobUid=self.test_job_uid
        hashcodes=["e1159037badca0a2a618f62c50eff1bb", ] # use your string hashcodes list here
        moveEnabled=False
        targetLocaleIds=["zh-TW",]
        res, status = self.jobs_api.addStringsToJob(translationJobUid=translationJobUid, hashcodes=hashcodes, moveEnabled=moveEnabled, targetLocaleIds=targetLocaleIds)
'''

testEnvironment = 'prod'


testDecorators = {

    'getJobFuzzyEstimateReports':TestData(
        {
            'translationJobUid' : Code('self.test_job_uid')
        },
        customTestCheck='''
assert_equal(res.data.totalCount, 1)
assert_equal(res.data.items[0]['translationJobUid'], self.test_job_uid)

'''
    ),

    'generateJobFuzzyEstimateReports':TestData(
        {
            'translationJobUid' : Code('self.test_job_uid'),
            'contentType' : 'JOB_CONTENT_ALL_CONTENT',
            'tags': ['some','tags'],
        },
        customTestCheck='''
self.report_uid = res.data.reportUid
assert_equal(res.data.reportType, 'FUZZY')
assert_equal(res.data.reportStatus, 'PENDING')
'''
    ),

    'getJobCostEstimateReports':TestData(
        {
            'translationJobUid' : Code('self.test_job_uid'),
            'reportStatus' : 'PENDING',
        },
    ),

    'generateJobCostEstimateReports':TestData(
        {
            'translationJobUid' : Code('self.test_job_uid'),
            'contentType' : 'JOB_CONTENT_ALL_CONTENT',
            'tags': ['some','tags'],
            'localeWorkflows': Code(' [ { "targetLocaleId": "zh-TW", "workflowUid": "748398939979" } ]'),
            'fuzzyProfileUid' : '624e06b333af',
        },
        customTestCheck='''
assert_equal(True, res.data.reportType in ('FUZZY','COST'))
assert_equal(True, res.data.reportStatus in ('PENDING'))
'''
    ),

    'getJobEstimateReportStatus':TestData(
        {
            'reportUid' : Code('self.report_uid'),
        },
        customTestCheck='''
assert_equal(True, res.data.reportStatus in ('PENDING', 'PROCESSING', 'COMPLETED'))
'''
    ),

    'getJobEstimateReport':TestData(
        {
            'reportUid' : Code('self.report_uid'),
        },
        customTestCheck='''
assert_equal(True, res.data.reportStatus in ('PENDING', 'PROCESSING', 'COMPLETED'))
'''
    ),

    'modifyJobEstimateReportTags':TestData(
        {
            'reportUid' : Code('self.report_uid'),
            'tags': ['tags','remodeling'],
        },
        customTestCheck='''
assert_equal(res.data.tags[0], 'tags')
assert_equal(res.data.tags[1], 'remodeling')
'''
    ),


    'exportJobEstimationReport':TestData(
        {
            'projectUid': Code('self.MY_PROJECT_ID'),
            'reportUid' : Code('self.report_uid'),
            'format' : 'csv'
        },
        [],
        customTestCheck='''
assert_equal(True, res.decode('utf-8').startswith('Project Name,Job Name,'))
''',
        isApiV2Response= False,
    ),



    'deleteJobEstimateReport':TestData(
        {
            'reportUid' : Code('self.report_uid'),
        },
    ),
}




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import os
import sys
import time, datetime

lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from smartlingApi.TagsApi import TagsApi
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.Credentials import Credentials

isPython3 =  sys.version_info[:2] >= (3,0)

def assert_equal(a,b, comment=''):
    if a != b :
        err = "Assertion Failed: '%s' != '%s' %s" % (a,b, comment)
        if not isPython3 and type(err) == str:
            err = err.decode('utf-8', 'ignore')
        raise Exception(repr(err))

class testTagsApi(object):

    CODE_SUCCESS_TOKEN = 'SUCCESS'
    ACCEPTED_TOKEN = 'ACCEPTED'

    def tearDown(self):
        print("tearDown", "OK")

    def setUp(self):
        credentials = Credentials('stg') #Gets your Smartling credetnials from environment variables
        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID

        #needed for testProjects
        self.MY_ACCOUNT_UID = credentials.MY_ACCOUNT_UID
        self.MY_LOCALE = credentials.MY_LOCALE

        if self.MY_ACCOUNT_UID == "CHANGE_ME":
            print("can't test projects api call, set self.MY_ACCOUNT_UID or export SL_ACCOUNT_UID=*********")
            return

        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None

        self.tags_api = TagsApi(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings, env='stg')

        print("setUp", "OK", "\n")


    def checkGetTagsListByProject(self):
        """
            method  :  GET
            api url :  /tags-api/v2/projects/{projectId}/tags
            as curl :  curl -H "Authorization: Bearer $smartlingToken" https://api.smartling.com/tags-api/v2/projects/$smartlingProjectId/tags
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getTagsListByProject
        """
        res, status = self.tags_api.getTagsListByProject()


        assert_equal(True, hasattr(res.data, 'items'))

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getTagsListByProject', 'OK')


    def checkGetAllTagsForStrings(self):
        """
            method  :  POST
            api url :  /tags-api/v2/projects/{projectId}/strings/tags/search
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingStringTagJSON" https://api.smartling.com/tags-api/v2/projects/$smartlingProjectId/strings/tags/search
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getAllTagsForStrings
        """
        stringHashcodes=['e1159037badca0a2a618f62c50eff1bb', ] # use your string hashcodes list here
        res, status = self.tags_api.getAllTagsForStrings(stringHashcodes=stringHashcodes)


        assert_equal(True, hasattr(res.data, 'items'))
        assert_equal('e1159037badca0a2a618f62c50eff1bb', res.data.items[0]['stringHashcode'])

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getAllTagsForStrings', 'OK')


    def checkAddTagToStrings(self):
        """
            method  :  POST
            api url :  /tags-api/v2/projects/{projectId}/strings/tags/add
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingStringTagJSON" https://api.smartling.com/tags-api/v2/projects/$smartlingProjectId/strings/tags/add
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/addTagToStrings
        """
        tags=['Uno', 'Dos']
        stringHashcodes=['e1159037badca0a2a618f62c50eff1bb', ] # use your string hashcodes list here
        res, status = self.tags_api.addTagToStrings(tags=tags, stringHashcodes=stringHashcodes)


        assert_equal([], res.errors)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('addTagToStrings', 'OK')


    def checkRemoveTagsFromStrings(self):
        """
            method  :  POST
            api url :  /tags-api/v2/projects/{projectId}/strings/tags/remove
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingStringTagJSON" https://api.smartling.com/tags-api/v2/projects/$smartlingProjectId/strings/tags/remove
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/removeTagsFromStrings
        """
        tags=['Uno', 'Dos']
        stringHashcodes=['e1159037badca0a2a618f62c50eff1bb', ] # use your string hashcodes list here
        res, status = self.tags_api.removeTagsFromStrings(tags=tags, stringHashcodes=stringHashcodes)


        assert_equal([], res.errors)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('removeTagsFromStrings', 'OK')


    def checkAddTagToStrings(self):
        """
            method  :  POST
            api url :  /tags-api/v2/projects/{projectId}/strings/tags/add
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingStringTagJSON" https://api.smartling.com/tags-api/v2/projects/$smartlingProjectId/strings/tags/add
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/addTagToStrings
        """
        tags=['Uno', 'Dos']
        stringHashcodes=['e1159037badca0a2a618f62c50eff1bb', ] # use your string hashcodes list here
        res, status = self.tags_api.addTagToStrings(tags=tags, stringHashcodes=stringHashcodes)


        assert_equal([], res.errors)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('addTagToStrings', 'OK')


    def checkRemoveAllTagsFromStrings(self):
        """
            method  :  POST
            api url :  /tags-api/v2/projects/{projectId}/strings/tags/remove/all
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingStringTagJSON" https://api.smartling.com/tags-api/v2/projects/$smartlingProjectId/strings/tags/remove/all
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/removeAllTagsFromStrings
        """
        stringHashcodes=['e1159037badca0a2a618f62c50eff1bb', ] # use your string hashcodes list here
        res, status = self.tags_api.removeAllTagsFromStrings(stringHashcodes=stringHashcodes)


        assert_equal([], res.errors)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('removeAllTagsFromStrings', 'OK')



def example():
    t = testTagsApi()
    t.setUp()
    t.checkGetTagsListByProject()
    t.checkGetAllTagsForStrings()
    t.checkAddTagToStrings()
    t.checkRemoveTagsFromStrings()
    t.checkAddTagToStrings()
    t.checkRemoveAllTagsFromStrings()
    t.tearDown()

example()




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""


from smartlingApiSdk.ApiV2 import ApiV2

class EstimatesApi(ApiV2):

    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None, permanentHeaders={}, env='prod'):
        ApiV2.__init__(self, userIdentifier, userSecret, projectId, proxySettings, permanentHeaders=permanentHeaders, env=env)

    def getJobFuzzyEstimateReports(self, translationJobUid, reportStatus='', contentCoverage='', creatorUserUids=[], translationJobSchemaContents=[], tags=[], createdFrom='', createdTo='', limit=0, offset=0, **kwargs):
        """
            method  :  GET
            api url :  /estimates-api/v2/projects/{projectId}/jobs/{translationJobUid}/reports/fuzzy
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getJobFuzzyEstimateReports
        """
        kw = {
            'reportStatus':reportStatus,
            'contentCoverage':contentCoverage,
            'creatorUserUids':creatorUserUids,
            'translationJobSchemaContents':translationJobSchemaContents,
            'tags':tags,
            'createdFrom':createdFrom,
            'createdTo':createdTo,
            'limit':limit,
            'offset':offset,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/estimates-api/v2/projects/{projectId}/jobs/{translationJobUid}/reports/fuzzy', translationJobUid=translationJobUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def generateJobFuzzyEstimateReports(self, translationJobUid, contentType, tags, **kwargs):
        """
            method  :  POST
            api url :  /estimates-api/v2/projects/{projectId}/jobs/{translationJobUid}/reports/fuzzy
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/generateJobFuzzyEstimateReports
        """
        kw = {
            'contentType':contentType,
            'tags':tags,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/estimates-api/v2/projects/{projectId}/jobs/{translationJobUid}/reports/fuzzy', translationJobUid=translationJobUid, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getJobCostEstimateReports(self, translationJobUid, reportStatus='', contentCoverage='', creatorUserUids=[], translationJobSchemaContents=[], tags=[], createdFrom='', createdTo='', limit=0, offset=0, **kwargs):
        """
            method  :  GET
            api url :  /estimates-api/v2/projects/{projectId}/jobs/{translationJobUid}/reports/cost
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getJobCostEstimateReports
        """
        kw = {
            'reportStatus':reportStatus,
            'contentCoverage':contentCoverage,
            'creatorUserUids':creatorUserUids,
            'translationJobSchemaContents':translationJobSchemaContents,
            'tags':tags,
            'createdFrom':createdFrom,
            'createdTo':createdTo,
            'limit':limit,
            'offset':offset,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/estimates-api/v2/projects/{projectId}/jobs/{translationJobUid}/reports/cost', translationJobUid=translationJobUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def generateJobCostEstimateReports(self, translationJobUid, contentType, tags, localeWorkflows, fuzzyProfileUid, **kwargs):
        """
            method  :  POST
            api url :  /estimates-api/v2/projects/{projectId}/jobs/{translationJobUid}/reports/cost
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/generateJobCostEstimateReports
        """
        kw = {
            'contentType':contentType,
            'tags':tags,
            'localeWorkflows':localeWorkflows,
            'fuzzyProfileUid':fuzzyProfileUid,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/estimates-api/v2/projects/{projectId}/jobs/{translationJobUid}/reports/cost', translationJobUid=translationJobUid, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getJobEstimateReportStatus(self, reportUid, reportStatus='', reportType='', **kwargs):
        """
            method  :  GET
            api url :  /estimates-api/v2/projects/{projectId}/reports/{reportUid}/status
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getJobEstimateReportStatus
        """
        kw = {
            'reportStatus':reportStatus,
            'reportType':reportType,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/estimates-api/v2/projects/{projectId}/reports/{reportUid}/status', reportUid=reportUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getJobEstimateReport(self, reportUid, reportStatus='', reportType='', **kwargs):
        """
            method  :  GET
            api url :  /estimates-api/v2/projects/{projectId}/reports/{reportUid}
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getJobEstimateReport
        """
        kw = {
            'reportStatus':reportStatus,
            'reportType':reportType,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/estimates-api/v2/projects/{projectId}/reports/{reportUid}', reportUid=reportUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def deleteJobEstimateReport(self, reportUid, **kwargs):
        """
            method  :  DELETE
            api url :  /estimates-api/v2/projects/{projectId}/reports/{reportUid}
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/deleteJobEstimateReport
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/estimates-api/v2/projects/{projectId}/reports/{reportUid}', reportUid=reportUid, **kwargs)
        response, status = self.command('DELETE', url, kw)
        return response, status


    def modifyJobEstimateReportTags(self, reportUid, tags, **kwargs):
        """
            method  :  PUT
            api url :  /estimates-api/v2/projects/{projectId}/reports/{reportUid}/tags
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/modifyJobEstimateReportTags
        """
        kw = {
            'tags':tags,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/estimates-api/v2/projects/{projectId}/reports/{reportUid}/tags', reportUid=reportUid, **kwargs)
        response, status = self.commandJson('PUT', url, kw)
        return response, status


    def exportJobEstimationReport(self, projectUid, reportUid, format, **kwargs):
        """
            method  :  GET
            api url :  /estimates-api/v2/projects/{projectUid}/reports/{reportUid}/download
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/exportJobEstimationReport
        """
        kw = {
            'format':format,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/estimates-api/v2/projects/{projectUid}/reports/{reportUid}/download', projectUid=projectUid, reportUid=reportUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import os
import sys
from nose.tools import assert_equal

lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from smartlingApi.AccountProjectsApi import AccountProjectsApi
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.Credentials import Credentials


class testProjetcsV2(object):

    CODE_SUCCESS_TOKEN = 'SUCCESS'


    def setUp(self):
        credentials = Credentials() #Gets your Smartling credetnials from environment variables
        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID

        #needed for testProjects
        self.MY_ACCOUNT_UID = credentials.MY_ACCOUNT_UID

        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None
        self.papi = AccountProjectsApi(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings)

        print("setUp", "OK", "\n\n\n")

    def tearDown(self):
        print("tearDown", "OK")

    def testProjects(self):
        if self.MY_ACCOUNT_UID == "CHANGE_ME":
            print("can't test projects api call, set self.MY_ACCOUNT_UID or export SL_ACCOUNT_UID=*********")
            return
        res, status = self.papi.getProjectsByAccount(self.MY_ACCOUNT_UID)

        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        projects = [x['projectId'] for x in res.data.items]

        assert_equal(True, self.MY_PROJECT_ID in projects)
        print("testProjects", "OK")

    def testProjectDetails(self):
        res, status = self.papi.getProjectDetails()

        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        assert_equal(self.MY_PROJECT_ID, res.data.projectId)

        print("testProjectDetails", "OK")




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""


from smartlingApiSdk.ApiV2 import ApiV2

class TagsApi(ApiV2):

    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None, permanentHeaders={}, env='prod'):
        ApiV2.__init__(self, userIdentifier, userSecret, projectId, proxySettings, permanentHeaders=permanentHeaders, env=env)

    def getTagsListByProject(self, tagMask='', limit=100, offset=0, **kwargs):
        """
            method  :  GET
            api url :  /tags-api/v2/projects/{projectId}/tags
            as curl :  curl -H "Authorization: Bearer $smartlingToken" https://api.smartling.com/tags-api/v2/projects/$smartlingProjectId/tags
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getTagsListByProject
        """
        kw = {
            'tagMask':tagMask,
            'limit':limit,
            'offset':offset,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/tags-api/v2/projects/{projectId}/tags', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getAllTagsForStrings(self, stringHashcodes, **kwargs):
        """
            method  :  POST
            api url :  /tags-api/v2/projects/{projectId}/strings/tags/search
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingStringTagJSON" https://api.smartling.com/tags-api/v2/projects/$smartlingProjectId/strings/tags/search
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getAllTagsForStrings
        """
        kw = {
            'stringHashcodes':stringHashcodes,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/tags-api/v2/projects/{projectId}/strings/tags/search', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def addTagToStrings(self, tags, stringHashcodes, **kwargs):
        """
            method  :  POST
            api url :  /tags-api/v2/projects/{projectId}/strings/tags/add
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingStringTagJSON" https://api.smartling.com/tags-api/v2/projects/$smartlingProjectId/strings/tags/add
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/addTagToStrings
        """
        kw = {
            'tags':tags,
            'stringHashcodes':stringHashcodes,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/tags-api/v2/projects/{projectId}/strings/tags/add', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def removeTagsFromStrings(self, tags, stringHashcodes, **kwargs):
        """
            method  :  POST
            api url :  /tags-api/v2/projects/{projectId}/strings/tags/remove
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingStringTagJSON" https://api.smartling.com/tags-api/v2/projects/$smartlingProjectId/strings/tags/remove
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/removeTagsFromStrings
        """
        kw = {
            'tags':tags,
            'stringHashcodes':stringHashcodes,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/tags-api/v2/projects/{projectId}/strings/tags/remove', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def removeAllTagsFromStrings(self, stringHashcodes, **kwargs):
        """
            method  :  POST
            api url :  /tags-api/v2/projects/{projectId}/strings/tags/remove/all
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingStringTagJSON" https://api.smartling.com/tags-api/v2/projects/$smartlingProjectId/strings/tags/remove/all
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/removeAllTagsFromStrings
        """
        kw = {
            'stringHashcodes':stringHashcodes,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/tags-api/v2/projects/{projectId}/strings/tags/remove/all', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status





#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import os
import sys
import time, datetime

lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from smartlingApi.ContextApi import ContextApi
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.Credentials import Credentials

isPython3 =  sys.version_info[:2] >= (3,0)

def assert_equal(a,b, comment=''):
    if a != b :
        err = "Assertion Failed: '%s' != '%s' %s" % (a,b, comment)
        if not isPython3 and type(err) == str:
            err = err.decode('utf-8', 'ignore')
        raise Exception(repr(err))

class testContextApi(object):

    CODE_SUCCESS_TOKEN = 'SUCCESS'
    ACCEPTED_TOKEN = 'ACCEPTED'

    def tearDown(self):
        print("tearDown", "OK")

    def setUp(self):
        credentials = Credentials('stg') #Gets your Smartling credetnials from environment variables
        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID

        #needed for testProjects
        self.MY_ACCOUNT_UID = credentials.MY_ACCOUNT_UID
        self.MY_LOCALE = credentials.MY_LOCALE

        if self.MY_ACCOUNT_UID == "CHANGE_ME":
            print("can't test projects api call, set self.MY_ACCOUNT_UID or export SL_ACCOUNT_UID=*********")
            return

        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None

        self.context_api = ContextApi(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings, env='stg')

        print("setUp", "OK", "\n")


    def checkUploadNewVisualContext(self):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/contexts
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -F "content=@context1.png;type=image/png" -F "name=context1.png" "https://api.smartling.com/context-api/v2/projects/$smartlingProjectId/contexts"
            Responses:
                200 : OK
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/uploadNewVisualContext
        """
        name='https://www.youtube.com/watch?v=0lJykuiS_9s'
        res, status = self.context_api.uploadNewVisualContext(name=name)


        assert_equal(res.data.contextType, 'VIDEO')
        assert_equal(res.data.name, 'https://www.youtube.com/watch?v=0lJykuiS_9s')

        res_img, status = self.context_api.uploadNewVisualContext(content='../resources/ctx_api_test.png')
        self.context_uid_img = res_img.data.contextUid

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('uploadNewVisualContext', 'OK')
        self.context_uid = res.data.contextUid


    def checkGetVisualContextsListByProject(self):
        """
            method  :  GET
            api url :  /context-api/v2/projects/{projectId}/contexts
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getVisualContextsListByProject
        """
        res, status = self.context_api.getVisualContextsListByProject()


        print('Total context count:',len(res.data.items))
        assert_equal(len(res.data.items) > 0, True)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getVisualContextsListByProject', 'OK')


    def checkGetVisualContextInfo(self):
        """
            method  :  GET
            api url :  /context-api/v2/projects/{projectId}/contexts/{contextUid}
            Responses:
                200 : OK
                404 : Context not found
            details :  https://api-reference.smartling.com/#operation/getVisualContextInfo
        """
        contextUid=self.context_uid
        res, status = self.context_api.getVisualContextInfo(contextUid=contextUid)


        assert_equal(res.data.contextType, 'VIDEO')
        assert_equal(res.data.name, 'https://www.youtube.com/watch?v=0lJykuiS_9s')

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getVisualContextInfo', 'OK')


    def checkDownloadVisualContextFileContent(self):
        """
            method  :  GET
            api url :  /context-api/v2/projects/{projectId}/contexts/{contextUid}/content
            Responses:
                200 : OK
                404 : Context not found
            details :  https://api-reference.smartling.com/#operation/downloadVisualContextFileContent
        """
        contextUid=self.context_uid_img
        res, status = self.context_api.downloadVisualContextFileContent(contextUid=contextUid)


        assert_equal(86324, len(res)) #empty for video context

        print('downloadVisualContextFileContent', 'OK')


    def checkRunAutomaticContextMatching(self):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/contexts/{contextUid}/match/async
            Responses:
                202 : ACCEPTED
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/runAutomaticContextMatching
        """
        contextUid=self.context_uid_img
        contentFileUri=''
        stringHashcodes=''
        overrideContextOlderThanDays=1
        res, status = self.context_api.runAutomaticContextMatching(contextUid=contextUid, contentFileUri=contentFileUri, stringHashcodes=stringHashcodes, overrideContextOlderThanDays=overrideContextOlderThanDays)


        self.match_id = res.data.matchId

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('runAutomaticContextMatching', 'OK')


    def checkUploadAndMatchVisualContext(self):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/contexts/upload-and-match-async
            Responses:
                202 : ACCEPTED
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/uploadAndMatchVisualContext
        """
        content='../resources/ctx_api_test.png'
        res, status = self.context_api.uploadAndMatchVisualContext(content=content)


        self.match_id_upl_n_match = res.data.matchId

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('uploadAndMatchVisualContext', 'OK')


    def checkGetAsyncContextMatchResults(self):
        """
            method  :  GET
            api url :  /context-api/v2/projects/{projectId}/match/{matchId}
            Responses:
                200 : OK
                404 : Match request expired or does not exist
            details :  https://api-reference.smartling.com/#operation/getAsyncContextMatchResults
        """
        matchId=self.match_id_upl_n_match
        res, status = self.context_api.getAsyncContextMatchResults(matchId=matchId)



        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getAsyncContextMatchResults', 'OK')


    def checkCreateStringToContextBindings(self):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/bindings
            Responses:
                200 : OK
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/createStringToContextBindings
        """
        bindings=[{'contextUid': self.context_uid, 'stringHashcode': 'ede6083ebd2594ca4e557612aaa05b2e'},
             {'contextUid': self.context_uid_img, 'stringHashcode': '4f25feab674accf572433f22dc516e2e'}]
        res, status = self.context_api.createStringToContextBindings(bindings=bindings)


        assert_equal(res.data.errors['totalCount'], 0)
        assert_equal(res.data.created['totalCount'], 2)
        items = res.data.created['items']
        self.binding_uno = items[0]['bindingUid']
        self.binding_dos = items[1]['bindingUid']

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('createStringToContextBindings', 'OK')


    def checkGetBindings(self):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/bindings/list
            Responses:
                200 : OK
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/getBindings
        """
        stringHashcodes=['ede6083ebd2594ca4e557612aaa05b2e', '4f25feab674accf572433f22dc516e2e']
        contentFileUri=''
        contextUid=''
        bindingUids=[]
        res, status = self.context_api.getBindings(stringHashcodes=stringHashcodes, contentFileUri=contentFileUri, contextUid=contextUid, bindingUids=bindingUids)


        print('Total bindings count:',len(res.data.items))
        assert_equal(len(res.data.items), 2)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getBindings', 'OK')


    def checkDeleteBindings(self):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/bindings/remove
            Responses:
                200 : OK
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/deleteBindings
        """
        stringHashcodes=[]
        contentFileUri=''
        contextUid=''
        bindingUids=[self.binding_uno, self.binding_dos]
        res, status = self.context_api.deleteBindings(stringHashcodes=stringHashcodes, contentFileUri=contentFileUri, contextUid=contextUid, bindingUids=bindingUids)


        assert_equal(res.data.totalCount, 2)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('deleteBindings', 'OK')


    def checkDeleteVisualContext(self):
        """
            method  :  DELETE
            api url :  /context-api/v2/projects/{projectId}/contexts/{contextUid}
            Responses:
                200 : OK
                404 : Context not found
            details :  https://api-reference.smartling.com/#operation/deleteVisualContext
        """
        contextUid=self.context_uid
        res, status = self.context_api.deleteVisualContext(contextUid=contextUid)


        res2, status = self.context_api.deleteVisualContext(contextUid=self.context_uid_img)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('deleteVisualContext', 'OK')



def example():
    t = testContextApi()
    t.setUp()
    t.checkUploadNewVisualContext()
    t.checkGetVisualContextsListByProject()
    t.checkGetVisualContextInfo()
    t.checkDownloadVisualContextFileContent()
    t.checkRunAutomaticContextMatching()
    t.checkUploadAndMatchVisualContext()
    t.checkGetAsyncContextMatchResults()
    t.checkCreateStringToContextBindings()
    t.checkGetBindings()
    t.checkDeleteBindings()
    t.checkDeleteVisualContext()
    t.tearDown()

example()



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

try:
    import json
except ImportError:
    import simplejson24 as json


class Data:
    """ provides dictionary items to be object attributes """
    def __init__(self, dict):
        self.dict = dict

    def __getattr__(self, key):
        return self.dict[key]

    def __str__(self):
        return repr(self.dict)


class ApiResponse:
    """ response object to store parsed json response as python object, it also behaves like string for backward
        compatibility with previous SDK versions where response was a string """
    def __init__(self, responseString, statusCode):
        self.statusCode = statusCode
        self.responseString = responseString
        self.responsDict = json.loads(responseString)
        self.parseResponse(responseString)

    def parseResponse(self, responseString):
        """ parses json and fills object attributes according json attributes """

        for k, v in list(self.responsDict['response'].items()):
            if k == 'data':
                self.data = Data(v)
            else:
                setattr(self, k, v)

    def __getattr__(self, key):
        """ provides string object methods to be available for response to behave like a string """
        if hasattr(self.responsDict, key):
            return getattr(self.responsDict, key)

        try:
            return getattr(self, key)
        except:
            pass

    def __str__(self):
        return str(self.responseString)



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limit
 """

import os
import sys

sys.path.append(os.path.abspath('../'))
isPython3 = sys.version_info[:2] >= (3, 0)

import json
import collections
from builder.ApiSource import ApiSource
from smartlingApiSdk.HttpClient import HttpClient
from smartlingApiSdk.Logger import Logger
from smartlingApiSdk.Settings import Settings


class ApiBuilder:
    """
    builds api based in openapi description for specific Api family defined as full_name
    """

    def __init__(self, fullName):
        self.api_name = fullName.replace(' ', '').replace('&', '')
        json_dict = self.getApiJson()
        self.apisrc = ApiSource(fullName, self.api_name)
        self.apisrc.collectMethods(json_dict)

    def getApiJson(self):
        httpLoader = HttpClient('api-reference.smartling.com')
        responseData, statusCode, headers = httpLoader.getHttpResponseAndStatus('GET', '/swagger.json', {})
        if 200 != statusCode:
            raise Exception('Can not load openapi description')
        if isPython3:
            responseData = responseData.decode('utf8')
        open("openapi3.json", 'w').write(responseData)
        jsonString = responseData
        return json.loads(jsonString, object_pairs_hook=collections.OrderedDict)

    def build(self):
        built = self.apisrc.build()
        outPath = '../smartlingApi/%sApi.py' % self.api_name
        open(outPath, 'w').write(built)
        print (built)
        return self  # Allow tagged calls : build().buildExample().buildTest()

    def buildExample(self):
        built = self.apisrc.buildExample()

        outPath = '../example/%sExample.py' % self.api_name
        open(outPath, 'w').write(built)
        print (built)
        return self  # Allow tagged calls : build().buildExample().buildTest()

    def buildTest(self):
        built = self.apisrc.buildTest()

        outPath = '../test/test%s.py' % self.api_name
        open(outPath, 'w').write(built)
        print (built)
        return self  # Allow tagged calls : build().buildExample().buildTest()


def main():
    sys.stdout = Logger('python-sdk', Settings.logLevel)
    ApiBuilder("Jobs").build().buildExample().buildTest()
    ApiBuilder("Job Batches V2").build().buildExample().buildTest()
    ApiBuilder("Strings").build().buildExample().buildTest()
    ApiBuilder("Context").build().buildExample().buildTest()
    ApiBuilder("Estimates").build().buildExample().buildTest()
    ApiBuilder("Account & Projects").build().buildExample().buildTest()
    ApiBuilder("Files").build().buildExample().buildTest()
    ApiBuilder("Tags").build().buildExample().buildTest()


if __name__ == '__main__':
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

#FileApi class implementation

from .Constants import Params, ReqMethod
from .ApiV2 import ApiV2

class FileApiV2(ApiV2):
    """ basic class implementing file api calls """

    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None, permanentHeaders={}):
        outdated = '''
This api is outdated and is not supported anymore!
You still can use it by commenting this exception.
But it is advised to use new api version.
Please check examples for current api usage.'''
        raise Exception(outdated)
        ApiV2.__init__(self, userIdentifier, userSecret, projectId, proxySettings, permanentHeaders=permanentHeaders)

    def commandGet(self, fileUri, locale, directives={}, **kw):
        """ https://developer.smartling.com/v1.0/reference#get_projects-projectid-locales-localeid-file """
        kw[Params.FILE_URI] = fileUri

        self.checkRetrievalType(kw)
        self.processDirectives(kw, directives)
        url = self.urlHelper.getUrl(self.urlHelper.GET, localeId=locale)

        resp, code, headers = self.getResponseAndStatus(ReqMethod.GET, url, kw)
        return resp, code

    def commandGetMultipleLocalesAsZip(self, fileUri, localeIds, directives={}, **kw):
        """ https://developer.smartling.com/v1.0/reference#get_projects-projectid-files-zip """
        kw[Params.FILE_URIS] = fileUri
        kw[Params.LOCALE_IDS] = localeIds

        self.checkRetrievalType(kw)
        self.processDirectives(kw, directives)

        resp, code, headers = self.getResponseAndStatus(ReqMethod.GET, self.urlHelper.getUrl(self.urlHelper.GET_MULTIPLE_LOCALES), kw)
        return resp, code

    def commandGetAllLocalesZip(self, fileUri, directives={}, **kw):
         """ http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/All-Locales """
         kw[Params.FILE_URI] = fileUri

         self.checkRetrievalType(kw)
         self.processDirectives(kw, directives)

         url = self.urlHelper.getUrl(self.urlHelper.GET_ALL_LOCALES_ZIP)

         resp, code, headers = self.getResponseAndStatus(ReqMethod.GET, url, kw)
         return resp, code


    def commandGetAllLocalesCsv(self, fileUri, directives={}, **kw):
         """  http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/All-Locales-CSV """
         kw[Params.FILE_URI] = fileUri

         self.checkRetrievalType(kw)
         self.processDirectives(kw, directives)

         url = self.urlHelper.getUrl(self.urlHelper.GET_ALL_LOCALES_CSV)
         resp, code, headers = self.getResponseAndStatus(ReqMethod.GET, url, kw)
         return resp, code


    def commandGetOriginal(self, fileUri):
        """  https://developer.smartling.com/v1.0/reference#get_projects-projectid-file """
        kw = {}
        kw[Params.FILE_URI] = fileUri

        url = self.urlHelper.getUrl(self.urlHelper.GET_ORIGINAL)
        resp, code, headers = self.getResponseAndStatus(ReqMethod.GET, url, kw)
        return resp, code

    def commandList(self, **kw):
        """ https://developer.smartling.com/v1.0/reference#list """
        url = self.urlHelper.getUrl(self.urlHelper.LIST_FILES)
        self.validateFileTypes(kw)

        return self.command(ReqMethod.GET, url, kw)

    def commandListFileTypes(self, **kw):
        """ https://developer.smartling.com/v1.0/reference#get_projects-projectid-file-types """
        return self.command(ReqMethod.GET, self.urlHelper.getUrl(self.urlHelper.LIST_FILE_TYPES), kw)

    def commandUpload(self, filePath, fileType, directives={}, **kw):
        """ https://developer.smartling.com/v1.0/reference#upload """
        params = {
                Params.FILE_URI: filePath,
                Params.FILE_TYPE: fileType,
                Params.FILE_PATH: filePath
            }

        for k,v in list(kw.items()):
            params[k] = v

        self.addLibIdDirective(params)
        self.processDirectives(params, directives)

        url = self.urlHelper.getUrl(self.urlHelper.UPLOAD)
        return self.uploadMultipart(url, params)

    def commandDelete(self, fileUri, **kw):
        """ https://developer.smartling.com/v1.0/reference#delete """
        kw[Params.FILE_URI] = fileUri
        uri = self.urlHelper.getUrl(self.urlHelper.DELETE)

        return self.command(ReqMethod.POST, uri, kw)

    def commandStatus(self, fileUri):
        """ https://developer.smartling.com/v1.0/reference#get_projects-projectid-file-status """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        url = self.urlHelper.getUrl(self.urlHelper.STATUS_ALL)
        return self.command(ReqMethod.GET, url, kw)

    def commandStatusLocale(self, fileUri, localeId):
        """ https://developer.smartling.com/v1.0/reference#get_projects-projectid-locales-localeid-file-status """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        url = self.urlHelper.getUrl(self.urlHelper.STATUS_LOCALE, localeId = localeId)
        return self.command(ReqMethod.GET, url, kw)

    def commandRename(self, fileUri, newFileUrl):
        """ https://developer.smartling.com/v1.0/reference#rename """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        kw[Params.FILE_URI_NEW] = newFileUrl
        url = self.urlHelper.getUrl(self.urlHelper.RENAME)
        return self.command(ReqMethod.POST, url, kw)

    def commandLastModified(self, fileUri, localeId, **kw):
        """ https://developer.smartling.com/v1.0/reference#last-modified """
        kw[Params.FILE_URI] = fileUri
        url = self.urlHelper.getUrl(self.urlHelper.LAST_MODIFIED, localeId = localeId)
        return self.command(ReqMethod.GET, url, kw)

    def commandLastModifiedAll(self, fileUri, **kw):
        """ https://developer.smartling.com/v1.0/reference#get_projects-projectid-file-last-modified """
        kw[Params.FILE_URI] = fileUri
        url = self.urlHelper.getUrl(self.urlHelper.LAST_MODIFIED_ALL)
        return self.command(ReqMethod.GET, url, kw)

    def commandImport(self, fileUriOriginal, filePathTranslated, fileType, localeId, directives={}, **kw):
        self.validateFileTypes({"fileTypes":fileType})
        params = {}
        params[Params.FILE_URI]  = fileUriOriginal
        params[Params.FILE_TYPE] = fileType
        params[Params.FILE_PATH] = filePathTranslated
        params["file"] = filePathTranslated + ";type=text/plain"

        for k,v in list(kw.items()):
            params[k] = v

        self.processDirectives(params, directives)

        url = self.urlHelper.getUrl(self.urlHelper.IMPORT, localeId = localeId)
        return self.uploadMultipart(url, params)

    def commandListAuthorizedLocales(self, fileUri):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Authorize-Content/List-Authorized-Locales/ """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        url = self.urlHelper.getUrl(self.urlHelper.LIST_AUTHORIZED_LOCALES)
        return self.command(ReqMethod.GET, url, kw)

    def commandAuthorize(self, fileUri, localeIds):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Authorize-Content/Authorize/ """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        kw[Params.LOCALE_IDS_BRACKET] = ",".join(localeIds)
        url = self.urlHelper.getUrl(self.urlHelper.AUTHORIZE)
        return self.command(ReqMethod.POST, url, kw)

    def commandUnauthorize(self, fileUri, localeIds):
        """  http://docs.smartling.com/pages/API/v2/FileAPI/Authorize-Content/Unauthorize/ """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        kw[Params.LOCALE_IDS_BRACKET] = ",".join(localeIds)
        url = self.urlHelper.getUrl(self.urlHelper.UNAUTHORIZE)
        return self.command(ReqMethod.DELETE, url, kw)

    def commandGetTranslations(self, fileUri, filePath, localeId, directives={}, **kw):
        """  https://developer.smartling.com/v1.0/reference#post_projects-projectid-locales-localeid-file-import """
        kw[Params.FILE_URI]  = fileUri
        kw[Params.FILE_PATH] = filePath
        kw["file"] = filePath + ";type=text/plain"

        self.processDirectives(kw, directives)

        url = self.urlHelper.getUrl(self.urlHelper.GET_TRANSLATIONS, localeId = localeId)
        return self.uploadMultipart(url, kw, response_as_string=True)




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""


from smartlingApiSdk.ApiV2 import ApiV2

class FilesApi(ApiV2):

    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None, permanentHeaders={}, env='prod'):
        ApiV2.__init__(self, userIdentifier, userSecret, projectId, proxySettings, permanentHeaders=permanentHeaders, env=env)

    def uploadSourceFile(self, file, fileUri, fileType, authorize=False, localeIdsToAuthorize=[], callbackUrl='', directives={}, **kwargs):
        """
            method  :  POST
            api url :  /files-api/v2/projects/{projectId}/file
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -F "file=@$uploadFilePath;type=text/plain" -F "fileUri=$uploadFileSmartlingUri" -F "fileType=$uploadFileSmartlingType" "https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file"
            Responses:
                200 : OK
                202 : ACCEPTED
                423 : The requested file is currently being processed by another operation. The file will be unlocked after the operation completes.
            details :  https://api-reference.smartling.com/#operation/uploadSourceFile
        """
        kw = {
            'file':self.processFile(file),
            'fileUri':fileUri,
            'fileType':fileType,
            'authorize':authorize,
            'localeIdsToAuthorize':localeIdsToAuthorize,
            'callbackUrl':callbackUrl,
        }
        self.addLibIdDirective(kw)
        self.processDirectives(kw, directives)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/file')
        return self.uploadMultipart(url, kw)


    def downloadSourceFile(self, fileUri, **kwargs):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/file
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -G --data-urlencode "fileUri=$smartlingFileUri" "https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file"
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/downloadSourceFile
        """
        kw = {
            'fileUri':fileUri,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/file', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getFileTranslationStatusAllLocales(self, fileUri, **kwargs):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/file/status
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getFileTranslationStatusAllLocales
        """
        kw = {
            'fileUri':fileUri,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/file/status', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getFileTranslationStatusSingleLocale(self, localeId, fileUri, **kwargs):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/locales/{localeId}/file/status
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getFileTranslationStatusSingleLocale
        """
        kw = {
            'fileUri':fileUri,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/locales/{localeId}/file/status', localeId=localeId, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def downloadTranslatedFileSingleLocale(self, localeId, fileUri, retrievalType='', includeOriginalStrings='', **kwargs):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/locales/{localeId}/file
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -o $smartlingLocaleId$smartlingFileUri -G --data-urlencode "fileUri=$smartlingFileUri" "https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/locales/$smartlingLocaleId/file"
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/downloadTranslatedFileSingleLocale
        """
        kw = {
            'fileUri':fileUri,
            'retrievalType':retrievalType,
            'includeOriginalStrings':includeOriginalStrings,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/locales/{localeId}/file', localeId=localeId, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def downloadTranslatedFilesAllLocales(self, fileUri, retrievalType='', includeOriginalStrings='', zipFileName='', **kwargs):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/locales/all/file/zip
            as curl :  curl -X GET -H "Authorization: Bearer $smartlingToken" 'https://api.smartling.com/files-api/v2/projects/{projectId}/locales/all/file/zip?fileUri=yourfile.json&retrievalType=published'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/downloadTranslatedFilesAllLocales
        """
        kw = {
            'fileUri':fileUri,
            'retrievalType':retrievalType,
            'includeOriginalStrings':includeOriginalStrings,
            'zipFileName':zipFileName,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/locales/all/file/zip', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def downloadMultipleTranslatedFiles(self, fileUris, localeIds, retrievalType='', includeOriginalStrings='', fileNameMode='', localeMode='', zipFileName='', **kwargs):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/files/zip
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/downloadMultipleTranslatedFiles
        """
        kw = {
            'fileUris':fileUris,
            'localeIds':localeIds,
            'retrievalType':retrievalType,
            'includeOriginalStrings':includeOriginalStrings,
            'fileNameMode':fileNameMode,
            'localeMode':localeMode,
            'zipFileName':zipFileName,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/files/zip', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getRecentlyUploadedSourceFilesList(self, uriMask='', fileTypes=[], lastUploadedAfter='', lastUploadedBefore='', orderBy='', limit=100, offset=0, **kwargs):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/files/list
            as curl :  curl -H "Authorization: Bearer $smartlingToken" "https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/files/list?fileTypes[]=json&uriMask=strings"
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getRecentlyUploadedSourceFilesList
        """
        kw = {
            'uriMask':uriMask,
            'fileTypes':fileTypes,
            'lastUploadedAfter':lastUploadedAfter,
            'lastUploadedBefore':lastUploadedBefore,
            'orderBy':orderBy,
            'limit':limit,
            'offset':offset,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/files/list', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getFileTypesList(self, **kwargs):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/file-types
            as curl :  curl -H "Authorization: Bearer $smartlingToken" "https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file-types"
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getFileTypesList
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/file-types', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def renameUploadedSourceFile(self, fileUri, newFileUri, **kwargs):
        """
            method  :  POST
            api url :  /files-api/v2/projects/{projectId}/file/rename
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -F "fileUri=filename.properties" -F "newFileUri=filename2.properties" 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file/rename'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/renameUploadedSourceFile
        """
        kw = {
            'fileUri':fileUri,
            'newFileUri':newFileUri,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/file/rename', **kwargs)
        response, status = self.command('POST', url, kw)
        return response, status


    def deleteUploadedSourceFile(self, fileUri, **kwargs):
        """
            method  :  POST
            api url :  /files-api/v2/projects/{projectId}/file/delete
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -F "fileUri=filename.properties" 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file/delete'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/deleteUploadedSourceFile
        """
        kw = {
            'fileUri':fileUri,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/file/delete', **kwargs)
        response, status = self.command('POST', url, kw)
        return response, status


    def getTranslatedFileLastModifiedDateSingleLocale(self, localeId, fileUri, lastModifiedAfter='', **kwargs):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/locales/{localeId}/file/last-modified
            as curl :  curl -X GET -H "Authorization: Bearer $smartlingToken" 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/locales/$smartlingLocaleId/file/last-modified?fileUri=filename.properties'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getTranslatedFileLastModifiedDateSingleLocale
        """
        kw = {
            'fileUri':fileUri,
            'lastModifiedAfter':lastModifiedAfter,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/locales/{localeId}/file/last-modified', localeId=localeId, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getTranslatedFileLastModifiedDateAllLocales(self, fileUri, lastModifiedAfter='', **kwargs):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/file/last-modified
            as curl :  curl -X GET -H "Authorization: Bearer $smartlingToken" 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file/last-modified?fileUri=filename.properties'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getTranslatedFileLastModifiedDateAllLocales
        """
        kw = {
            'fileUri':fileUri,
            'lastModifiedAfter':lastModifiedAfter,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/file/last-modified', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def importFileTranslations(self, localeId, file, fileUri, fileType, translationState, overwrite='', **kwargs):
        """
            method  :  POST
            api url :  /files-api/v2/projects/{projectId}/locales/{localeId}/file/import
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -F "file=@filename.properties" -F "fileUri=filename.properties" -F "fileType=javaProperties" -F "translationState=PUBLISHED" 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/locales/$smartlingLocaleId/file/import'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/importFileTranslations
        """
        kw = {
            'file':self.processFile(file),
            'fileUri':fileUri,
            'fileType':fileType,
            'translationState':translationState,
            'overwrite':overwrite,
        }
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/locales/{localeId}/file/import', localeId=localeId)
        return self.uploadMultipart(url, kw)


    def exportFileTranslations(self, localeId, file, fileUri, retrievalType='', includeOriginalStrings='', **kwargs):
        """
            method  :  POST
            api url :  /files-api/v2/projects/{projectId}/locales/{localeId}/file/get-translations
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -F "file=@filename.properties" -F 'fileUri=filename.properties' 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/locales/$smartlingLocaleId/file/get-translations'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/exportFileTranslations
        """
        kw = {
            'file':self.processFile(file),
            'fileUri':fileUri,
            'retrievalType':retrievalType,
            'includeOriginalStrings':includeOriginalStrings,
        }
        url = self.urlHelper.getUrl('/files-api/v2/projects/{projectId}/locales/{localeId}/file/get-translations', localeId=localeId)
        return self.uploadMultipart(url, kw)


    def getRecentlyPublishedFilesList(self, publishedAfter, fileUris=[], localeIds=[], offset=0, limit=0, **kwargs):
        """
            method  :  GET
            api url :  /published-files-api/v2/projects/{projectId}/files/list/recently-published
            as curl :  curl -H "Authorization: Bearer $smartlingToken" 'https://api.smartling.com/published-files-api/v2/projects/$smartlingProjectId/files/list/recently-published?publishedAfter=2019-11-21T11:51:17Z&fileUris[]=files/example1.json&localeIds[]=fr-CA&limit=10&offset=100'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getRecentlyPublishedFilesList
        """
        kw = {
            'publishedAfter':publishedAfter,
            'fileUris':fileUris,
            'localeIds':localeIds,
            'offset':offset,
            'limit':limit,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/published-files-api/v2/projects/{projectId}/files/list/recently-published', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status





#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""


from smartlingApiSdk.ApiV2 import ApiV2

class AccountProjectsApi(ApiV2):

    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None, permanentHeaders={}, env='prod'):
        ApiV2.__init__(self, userIdentifier, userSecret, projectId, proxySettings, permanentHeaders=permanentHeaders, env=env)

    def getProjectsByAccount(self, accountUid, projectNameFilter='', includeArchived='', offset=0, limit=0, **kwargs):
        """
            method  :  GET
            api url :  /accounts-api/v2/accounts/{accountUid}/projects
            as curl :  curl -H "Authorization: Bearer $smartlingToken" https://api.smartling.com/accounts-api/v2/accounts/$smartlingAccountId/projects
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getProjectsByAccount
        """
        kw = {
            'projectNameFilter':projectNameFilter,
            'includeArchived':includeArchived,
            'offset':offset,
            'limit':limit,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/accounts-api/v2/accounts/{accountUid}/projects', accountUid=accountUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getProjectDetails(self, includeDisabledLocales='', **kwargs):
        """
            method  :  GET
            api url :  /projects-api/v2/projects/{projectId}
            as curl :  curl -H "Authorization: Bearer $smartlingToken" https://api.smartling.com/projects-api/v2/projects/$smartlingProjectId
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getProjectDetails
        """
        kw = {
            'includeDisabledLocales':includeDisabledLocales,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/projects-api/v2/projects/{projectId}', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def addLocaleToProject(self, defaultWorkflowUid, localeId, **kwargs):
        """
            method  :  POST
            api url :  /projects-api/v2/projects/{projectId}/targetLocales
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/addLocaleToProject
        """
        kw = {
            'defaultWorkflowUid':defaultWorkflowUid,
            'localeId':localeId,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/projects-api/v2/projects/{projectId}/targetLocales', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def copyProject(self, projectName, targetLocaleIds, **kwargs):
        """
            method  :  POST
            api url :  /projects-api/v2/projects/{projectId}/copy
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/copyProject
        """
        kw = {
            'projectName':projectName,
            'targetLocaleIds':targetLocaleIds,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/projects-api/v2/projects/{projectId}/copy', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getProjectCopyRequestStatus(self, processUid, **kwargs):
        """
            method  :  GET
            api url :  /projects-api/v2/projects/{projectId}/copy/{processUid}
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getProjectCopyRequestStatus
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/projects-api/v2/projects/{projectId}/copy/{processUid}', processUid=processUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

from .HttpClient import HttpClient
from .ApiResponse import ApiResponse
from .Constants import ReqMethod

import time


class AuthClient:
    authUri = "/auth-api/v2/authenticate"
    refreshUri = "/auth-api/v2/authenticate/refresh"
    timeJitter = 5  # Seconds off server expiration time

    def __init__(self, host, userIdentifier, userSecret, proxySettings=None):
        self.httpClient = HttpClient(host, proxySettings)
        self.userIdentifier = userIdentifier
        self.userSecret = userSecret
        self.accessExpiresAt = 0
        self.refreshExpiresAt = 0

    def request(self, uri, body):
        header = {"Content-Type": "application/json"}
        body = body.encode()
        response_data, status_code, headers = self.httpClient.getHttpResponseAndStatus(
            ReqMethod.POST, uri, params={}, extraHeaders=header, requestBody=body)
        apiResponse = ApiResponse(response_data, status_code)

        now = time.time()
        try:
            self.accessToken = apiResponse.data.accessToken
            self.refreshToken = apiResponse.data.refreshToken
            self.accessExpiresAt = now + apiResponse.data.expiresIn - self.timeJitter
            self.refreshExpiresAt = now + apiResponse.data.refreshExpiresIn - self.timeJitter
        except Exception as e:
            print(e)
            self.accessToken = None

    def authenticate(self):
        body = '{"userIdentifier": "%s", "userSecret": "%s"}' % (self.userIdentifier, self.userSecret)
        if '@smartling.com' in self.userIdentifier:
            self.request(self.authUri + '/user', body)
        else:
            self.request(self.authUri, body)

    def refresh(self):
        body = '{"refreshToken":"%s"}' % self.refreshToken
        self.request(self.refreshUri, body)

    def getToken(self):
        if not getattr(self, 'accessToken', None):
            self.authenticate()
            return self.accessToken

        now = time.time()
        if now >= self.accessExpiresAt:
            if now >= self.refreshExpiresAt:
                self.refresh()
            else:
                self.authenticate()
        return self.accessToken



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

#FileApi class implementation

from .HttpClient import HttpClient, isPython3
from .MultipartPostHandler import MultipartPostHandler
from .Constants import Params, ReqMethod
from .ApiResponse import ApiResponse
from .Logger import Logger
from .Settings import Settings
import io
import sys
import logging
import json


class FileApiBase:
    """ basic class implementing low-level api calls """
    response_as_string = False

    def __init__(self, host, apiKey, projectId, proxySettings=None, permanentHeaders={}):
        self.host = host
        self.apiKey = apiKey
        self.projectId = projectId
        self.proxySettings = proxySettings
        self.httpClient = HttpClient(host, proxySettings, permanentHeaders=permanentHeaders)
        sys.stdout = Logger('python-sdk', Settings.logLevel)
        sys.stderr = Logger('STDERR', logging.ERROR)

    def addAuth(self, params):
        params[Params.API_KEY] = self.apiKey
        params[Params.PROJECT_ID] = self.projectId
        return {}

    def processFile(self, file):
        """"
            returns file-like object form string or file
            tries to treat string as file path or make it file-like object to be uploaded
        """
        if not file or file==type(file):
            return file
        try:
            f = open(file, 'rb')
        except:
            f = io.StringIO(file)
            f.seek(0)
        return f

    def filterOutDefaults(self, params):
        if hasattr(params, 'items'):
            for k, v in list(params.items()):
                if bool == type(v): continue
                if not v: del params[k]
                if k == 'projectId': del params[k]

    def uploadMultipart(self, uri, params, response_as_string=False):
        self.filterOutDefaults(params)
        authHeader = self.addAuth(params)
        if Params.FILE_PATH in params:
            params[Params.FILE] = open(params[Params.FILE_PATH], 'rb')
            del params[Params.FILE_PATH]  # no need in extra field in POST

        response_data, status_code, headers = self.getHttpResponseAndStatus(ReqMethod.POST ,uri, params, MultipartPostHandler, extraHeaders = authHeader)
        response_data = response_data.strip()
        if self.response_as_string or response_as_string or not self.isJsonResponse(headers):
            return response_data, status_code
        return ApiResponse(response_data, status_code), status_code

    def commandJson(self, method, uri, params):
        authHeader = self.addAuth(params)
        authHeader['Content-Type'] = 'application/json'
        self.filterOutDefaults(params)
        jsonBody = json.dumps(params).encode('utf8')

        data, code, headers = self.httpClient.getHttpResponseAndStatus(method, uri, params={}, requestBody = jsonBody, extraHeaders = authHeader)
        if not code in [200,202]:
            print ("code:%d jsonBody=%s" % (code, jsonBody))

        if self.response_as_string or not self.isJsonResponse(headers):
            return data, code
        return  ApiResponse(data, code), code

    def getHttpResponseAndStatus(self, method, uri, params, handler=None, extraHeaders = None):
        return self.httpClient.getHttpResponseAndStatus(method, uri, params, handler, extraHeaders = extraHeaders)
  
    def getResponseAndStatus(self, method, uri, params):
        authHeader = self.addAuth(params)
        return self.getHttpResponseAndStatus(method, uri, params, extraHeaders = authHeader)

    def isJsonResponse(self, headers):
        if isPython3:
            hdr = 'Content-Type'
        else:
            hdr = 'content-type'
        return 'json' in headers.get(hdr,'')

    def command(self, method, uri, params):
        self.filterOutDefaults(params)
        data, code, headers = self.getResponseAndStatus(method, uri, params)
        if self.response_as_string or not self.isJsonResponse(headers):
            return data, code
        return  ApiResponse(data, code), code
